/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: interpol.h,v 1.4 2002/05/08 21:24:48 jdejong Exp $ */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: interpol.h,v 1.4 2002/05/08 21:24:48 jdejong Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jdejong 2002-05-08  imported
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */

/*---------------------------------------------------------------------- -*/
/*    Utility module for interpolating in arrays                          */
/*----------------------------------------------------------------------- */
#ifndef INTERPOL_H
#define INTERPOL_H

float imintp (float *array, int nx, int ny, int half, 
	      float xpix, float ypix, float fblank);
/*----------------------------------------------------------------------- */
/*   Interpolate value.  Returned value blanked if outside image or most  */
/*   data blanked.  Arguments are in pixels.                              */
/*   Inputs:                                                              */
/*      array    data array to be interpolated                            */
/*      nx       dimension of array in "X" (fastest dimension)            */
/*      ny       dimension of array in "Y" (slowest varying dimension)    */
/*      half     interpolation half width in range (1,4)                  */
/*      xpix     pixel location (0-rel) on X axis to interpolate at       */
/*      ypix     pixel location (0-rel) on Y axis to interpolate at       */
/*      fblank   magic blanking value for array                           */
/*   Returns:                                                             */
/*      Interpolated value.                                               */
/*----------------------------------------------------------------------- */

void cxintp (float cxout[2], float *array, int nx, int half, 
	      float xpix, float fblank);
/*----------------------------------------------------------------------- */
/*   Interpolate complex value.  Returned values blanked if outside array */
/*   or most data blanked.  Arguments are in pixels.                      */
/*   Inputs:                                                              */
/*      array    data array to be interpolated as (real, imag)            */
/*      nx       dimension of array.                                      */
/*      half     interpolation half width in range (1,4)                  */
/*      xpix     pixel location (0-rel) to interpolate at                 */
/*      fblank   magic blanking value for array                           */
/*   Outputs:                                                             */
/*      cxout    returned complex value as real, imaginary                */
/*----------------------------------------------------------------------- */

void iminfn (float pos, int n, int ihalf, float *intr, int *cen);
/*----------------------------------------------------------------------- */
/*   Returns Lagrangian interpolation weights.  Adjustments are made to   */
/*   account for the ends of the data.                                    */
/*   Inputs:                                                              */
/*      pos      Coordinate to interpolate at on axis                     */
/*      n        Maximum pixel number on axis                             */
/*      ihalf    half width in pixels of interpolation kernal             */
/*   Output:                                                              */
/*      intr     Interpolation array                                      */
/*                (1) = pos                                               */
/*                (2...) interpolation weights.                           */
/*      cen      (First - 1) pixel number for use                         */
/*----------------------------------------------------------------------- */

#endif  /* INTERPOL_H */









/* */
